# [프로젝트명] 개발 가이드라인

모든 기능 계획에서 자동 생성됨. 최종 업데이트: [DATE]

## 활성 기술

[모든 PLAN.MD 파일에서 추출]

## 프로젝트 구조

```text
[계획의 실제 구조]
```

## 명령어

[활성 기술에 대한 명령어만]

## 코드 스타일

[사용 중인 언어에 대해서만, 언어별]

## 최근 변경사항

[최근 3개 기능과 추가된 내용]

<!-- 수동 추가 시작 -->
<!-- 수동 추가 끝 -->
